@@ -8,9 +8,11 @@ from odecloud.client import OdeCloud, AsyncOdeCloud
 from odecloud.exceptions import (
     OdeCloudError,
     AuthenticationError,
+    ForbiddenError,
     RateLimitError,
     NotFoundError,
     ValidationError,
+    ServerError,
 )
 from odecloud.models.time_entries import (
     TimeEntry,
@@ -21,7 +23,7 @@ from odecloud.models.time_entries import (
 from odecloud.models.projects import Project, ProjectDetail, Task
 from odecloud.models.profile import Profile, ProfileUpdate, SocialLinks, WorkExperience
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 __all__ = [
     # Client
@@ -30,9 +32,11 @@ __all__ = [
     # Exceptions
     "OdeCloudError",
     "AuthenticationError",
+    "ForbiddenError",
     "RateLimitError",
     "NotFoundError",
     "ValidationError",
+    "ServerError",
     # Time Entry Models
     "TimeEntry",
     "TimeEntryCreate",
